"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeService = void 0;
const common_1 = require("@nestjs/common");
const default_service_1 = require("../../../common/service/default.service");
const code_entity_1 = require("./entity/code.entity");
let CodeService = class CodeService extends default_service_1.DefaultService {
    async find(dto) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager
            .createQueryBuilder(code_entity_1.Code, 'code')
            .select(['code.*']);
        if (dto.rootFl) {
            qb.andWhere('rootFl=:rootFl', { rootFl: dto.rootFl });
        }
        if (dto.codeKey) {
            qb.andWhere('codeKey=:codeKey', { codeKey: dto.codeKey });
        }
        if (dto.codeName) {
            qb.andWhere('codeName like :codeName', {
                codeName: '%' + dto.codeName + '%',
            });
        }
        if (dto.codeValue) {
            qb.andWhere('codeValue=:codeValue', { codeValue: dto.codeValue });
        }
        if (dto.parentKey) {
            qb.andWhere('parentKey=:parentKey', { parentKey: dto.parentKey });
        }
        return qb.getRawMany();
    }
    async findOne(codeKey) {
        const entityManager = await this.getEntityManager();
        return await entityManager.findOne(code_entity_1.Code, {
            where: {
                codeKey: codeKey,
            },
        });
    }
    async create(dto) {
        if (dto.codeKey) {
            const isExist = await this.findOne(dto.codeKey);
            if (isExist)
                throw new common_1.HttpException('이미 등록 된 품목입니다.', common_1.HttpStatus.BAD_REQUEST);
        }
        return super.createBase(code_entity_1.Code, dto);
    }
    async update(dto) {
        if (dto.codeKey) {
            const isExist = await this.findOne(dto.codeKey);
            if (!isExist)
                throw new common_1.HttpException('코드키를 확인하세요.', common_1.HttpStatus.BAD_REQUEST);
            const entityManager = await this.getEntityManager();
            return await entityManager.update(code_entity_1.Code, {
                codeKey: dto.codeKey,
            }, Object.assign({}, dto));
        }
        throw new common_1.HttpException('코드키를 확인하세요.', common_1.HttpStatus.BAD_REQUEST);
    }
    async delete(codeKey) {
        const childCode = await this.getCodeChildren(codeKey);
        if (childCode.length > 0) {
            throw new common_1.HttpException('하위코드를 먼저 삭제하세요.', common_1.HttpStatus.BAD_REQUEST);
        }
        const entityManager = await this.getEntityManager();
        return (await entityManager.delete(code_entity_1.Code, { codeKey }))
            ? { result: true }
            : { result: false };
    }
    async getCodeChildren(codeKey) {
        const entityManager = await this.getEntityManager();
        const childCode = await entityManager.findBy(code_entity_1.Code, { parentKey: codeKey });
        return childCode;
    }
    async getHierarchy(codeKey) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager
            .createQueryBuilder(code_entity_1.Code, 'code')
            .select(['code.*']);
        qb.andWhere('codeKey like :codeKey', {
            codeKey: codeKey + '%',
        });
        qb.orderBy('codeKey', 'ASC');
        return qb.getRawMany();
    }
};
exports.CodeService = CodeService;
exports.CodeService = CodeService = __decorate([
    (0, common_1.Injectable)()
], CodeService);
//# sourceMappingURL=code.service.js.map