"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ManagerService = void 0;
const common_1 = require("@nestjs/common");
const default_service_1 = require("../../../common/service/default.service");
const manager_entity_1 = require("./entity/manager.entity");
const gsUtil_1 = require("../../../common/util/gsUtil");
const bcrypt_1 = require("bcrypt");
const partner_entity_1 = require("../partner/entity/partner.entity");
let ManagerService = class ManagerService extends default_service_1.DefaultService {
    async find(dto) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager.createQueryBuilder(manager_entity_1.Manager, 'manager');
        qb.leftJoinAndSelect('gs_partner', 'partner', 'manager.partnerSno = partner.sno').select([
            'manager.sno as sno',
            'managerType as managerType',
            'manager.id as id',
            'manager.managerName as managerName',
            'manager.managerTel as managerTel',
            'manager.managerEmail as managerEmail',
            'manager.status as status',
            'manager.authority as authority',
            'manager.additionalInfo as additionalInfo',
            'manager.regDt as regDt',
            'manager.updateDt as updateDt',
            'partner.partnerName as partnerName',
            'partner.siteUrl as siteUrl',
            'partner.ceoName as ceoName',
            'partner.companyTel as companyTel',
            'partner.companyNo as companyNo',
        ]);
        if (dto.id) {
            qb.andWhere('manager.id LIKE :id', {
                id: `%${dto.id}%`,
            });
        }
        if (dto.managerName) {
            qb.andWhere('manager.managerName LIKE :managerName', {
                managerName: `%${dto.managerName}%`,
            });
        }
        if (dto.partnerSno) {
            qb.andWhere('manager.partnerSno = :partnerSno', {
                partnerSno: dto.partnerSno,
            });
        }
        if (dto.status) {
            qb.andWhere('manager.status = :status', {
                status: dto.status,
            });
        }
        if (dto.managerType) {
            qb.andWhere('manager.managerType = :managerType', {
                managerType: dto.managerType,
            });
        }
        qb.offset(dto.skip);
        qb.limit(dto.take);
        qb.orderBy('manager.sno', dto.order);
        const list = await qb.getRawMany();
        const count = await qb.getCount();
        const data = [list, count];
        return (0, gsUtil_1.paginateResponse)(data, dto.page, dto.take);
    }
    async findOne(managerSno) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager.createQueryBuilder(manager_entity_1.Manager, 'manager');
        qb.leftJoinAndSelect('gs_partner', 'partner', 'manager.partnerSno = partner.sno')
            .select([
            'manager.sno as sno',
            'managerType as managerType',
            'manager.id as id',
            'manager.managerName as managerName',
            'manager.managerTel as managerTel',
            'manager.managerEmail as managerEmail',
            'manager.status as status',
            'manager.authority as authority',
            'manager.accessToken as accessToken',
            'manager.additionalInfo as additionalInfo',
            'manager.regDt as regDt',
            'manager.updateDt as updateDt',
            'partner.partnerName as partnerName',
            'partner.siteUrl as siteUrl',
            'partner.ceoName as ceoName',
            'partner.companyTel as companyTel',
            'partner.companyNo as companyNo',
        ])
            .andWhere('manager.sno=:managerSno', { managerSno: managerSno });
        const manager = await qb.getRawOne();
        return manager;
    }
    async findOneById(id) {
        const entityManager = await this.getEntityManager();
        return await entityManager.findOneBy(manager_entity_1.Manager, { id });
    }
    async create(dto) {
        const entityManager = await this.getEntityManager();
        const isExist = await entityManager.findOneBy(manager_entity_1.Manager, { id: dto.id });
        const partnerExist = await entityManager.findOneBy(partner_entity_1.Partner, {
            sno: dto.partnerSno,
        });
        if (isExist)
            throw new common_1.HttpException('아이디가 이미 존재합니다.', common_1.HttpStatus.BAD_REQUEST);
        if (!partnerExist)
            throw new common_1.HttpException('고객사를 확인하세요.', common_1.HttpStatus.BAD_REQUEST);
        dto.pwd = await (0, bcrypt_1.hash)(dto.pwd, 10);
        return super.createBase(manager_entity_1.Manager, dto);
    }
    async update(dto) {
        return super.updateBase(manager_entity_1.Manager, dto);
    }
    async delete(sno) {
        return super.delete(manager_entity_1.Manager, sno);
    }
    async profile(sno) {
        const entityManager = await this.getEntityManager();
        const manager = await entityManager
            .createQueryBuilder(manager_entity_1.Manager, 'manager')
            .select([
            'manager.sno',
            'manager.id',
            'manager.managerType',
            'manager.managerName',
            'manager.managerTel',
            'manager.managerEmail',
            'manager.partnerSno',
            'manager.authority',
            'manager.additionalInfo',
        ])
            .where('manager.sno = :sno', { sno })
            .getOne();
        return manager;
    }
};
exports.ManagerService = ManagerService;
exports.ManagerService = ManagerService = __decorate([
    (0, common_1.Injectable)()
], ManagerService);
//# sourceMappingURL=manager.service.js.map