"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PartnerService = void 0;
const common_1 = require("@nestjs/common");
const partner_entity_1 = require("./entity/partner.entity");
const default_service_1 = require("../../../common/service/default.service");
const core_1 = require("@nestjs/core");
const gsUtil_1 = require("../../../common/util/gsUtil");
const manager_entity_1 = require("../manager/entity/manager.entity");
const app_partner_service_1 = require("../app-partner/app-partner.service");
const auth_service_1 = require("../../common/auth/auth.service");
let PartnerService = class PartnerService extends default_service_1.DefaultService {
    constructor(appPartnerService, authService, moduleRef) {
        super(moduleRef);
        this.appPartnerService = appPartnerService;
        this.authService = authService;
        this.moduleRef = moduleRef;
    }
    async find(dto) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager
            .createQueryBuilder(partner_entity_1.Partner, 'partner')
            .select(['partner.*']);
        if (dto.companyNo) {
            qb.andWhere('companyNo LIKE :companyNo', {
                companyNo: `%${dto.companyNo}%`,
            });
        }
        if (dto.partnerName) {
            qb.andWhere('partnerName LIKE :partnerName', {
                partnerName: `%${dto.partnerName}%`,
            });
        }
        qb.offset(dto.skip);
        qb.limit(dto.take);
        qb.orderBy('sno', dto.order);
        const list = await qb.getRawMany();
        const count = await qb.getCount();
        const data = [list, count];
        return (0, gsUtil_1.paginateResponse)(data, dto.page, dto.take);
    }
    async findOne(partnerSno) {
        const entityManager = await this.getEntityManager();
        return await entityManager.findOne(partner_entity_1.Partner, {
            where: {
                sno: partnerSno,
            },
        });
    }
    async create(dto) {
        const partner = await super.createBase(partner_entity_1.Partner, dto);
        const appToken = await this.authService.getAppToken(await partner.sno);
        this.update({
            sno: partner.sno,
            appToken: appToken,
        });
        return partner;
    }
    async update(dto) {
        return super.updateBase(partner_entity_1.Partner, dto);
    }
    async delete(sno) {
        const entityManager = await this.getEntityManager();
        const manager = await entityManager.findBy(manager_entity_1.Manager, {
            partnerSno: sno,
        });
        if (manager.length > 0)
            throw new common_1.HttpException('관리자 삭제 후 고객사를 삭제하세요.', common_1.HttpStatus.BAD_REQUEST);
        return super.delete(partner_entity_1.Partner, sno);
    }
    async addApp(dto) {
        dto.appSno.map(async (sno) => {
            return await this.appPartnerService.create({
                appSno: sno,
                partnerSno: [dto.partnerSno],
            });
        });
        return await this.appPartnerService.find(dto.partnerSno);
    }
};
exports.PartnerService = PartnerService;
exports.PartnerService = PartnerService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [app_partner_service_1.AppPartnerService,
        auth_service_1.AuthService,
        core_1.ModuleRef])
], PartnerService);
//# sourceMappingURL=partner.service.js.map