"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InfoBankService = void 0;
const common_1 = require("@nestjs/common");
const axios_1 = __importDefault(require("axios"));
const gsUtil_1 = require("../../../../common/util/gsUtil");
class InfoBankService {
    async getToken(alimtalkManager) {
        const api = process.env.INFOBANK_AUTH_API;
        const clientKey = alimtalkManager.clientKey;
        const clientPwd = alimtalkManager.clientPwd;
        const headers = {
            'X-IB-Client-Id': clientKey,
            'X-IB-Client-Passwd': clientPwd,
        };
        const response = await axios_1.default
            .post(api, {
            headers: headers,
        })
            .catch(function (error) {
            throw new common_1.HttpException(error.response.data.text, error.response.data.status);
        });
        const accessKey = response.data.accessToken;
        return { clientKey, clientPwd, accessKey };
    }
    async sendAlimtalk(receiver, content, alimtalkManager, alimtalkTemplate, attachment) {
        receiver = (0, gsUtil_1.convertGlobalTelNo)(receiver);
        const headers = {
            'X-IB-Client-Id': alimtalkManager.clientKey,
            'X-IB-Client-Passwd': alimtalkManager.clientPwd,
        };
        const params = {
            msg_type: 'AL',
            msg_data: {
                senderid: alimtalkManager.senderInfo,
                to: receiver,
                content: content,
            },
            msg_attr: {
                sender_key: alimtalkManager.profileKey,
                response_method: 'realtime',
                template_code: alimtalkTemplate.templateCode,
                attachment: JSON.parse(attachment),
            },
        };
        const api = 'https://msggw.supersms.co:9443/v1/send/kko';
        const response = await axios_1.default
            .post(api, params, {
            headers: headers,
        })
            .catch(function (error) {
            throw new common_1.HttpException(error.response.data.text, error.response.data.status);
        });
        response.data.content = content;
        return response.data;
    }
}
exports.InfoBankService = InfoBankService;
//# sourceMappingURL=infoBank.service.js.map