"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BrandManagerService = void 0;
const common_1 = require("@nestjs/common");
const enum_1 = require("../../../common/enum/enum");
const default_service_1 = require("../../../common/service/default.service");
const brand_manager_entity_1 = require("./entity/brand-manager.entity");
const gsUtil_1 = require("../../../common/util/gsUtil");
const partner_service_1 = require("../../admin/partner/partner.service");
const core_1 = require("@nestjs/core");
let BrandManagerService = class BrandManagerService extends default_service_1.DefaultService {
    constructor(partnerService, moduleRef) {
        super(moduleRef);
        this.partnerService = partnerService;
        this.moduleRef = moduleRef;
    }
    async create(dto) {
        var _a;
        const partner = await this.partnerService.findOne(dto.partnerSno);
        if (!partner.longLivedToken)
            throw new common_1.HttpException('인증토큰이 없습니다. 인증토큰을 먼저 발급하세요', common_1.HttpStatus.BAD_REQUEST);
        const param = [
            {
                parentNo: dto.parentNo,
                subName: dto.subName,
                mainName: dto.mainName,
                description: dto.description,
                displayAreaContentUrl: dto.displayAreaContentUrl,
                extraInfo: (_a = dto.extraInfo) !== null && _a !== void 0 ? _a : '',
                children: [],
            },
        ];
        const result = await (0, gsUtil_1.shopByServerApi)('/brands', enum_1.HTTP_METHOD.POST, partner.systemKey, partner.longLivedToken, param, '2.0');
        const brand = await this.sync(partner.sno, partner.systemKey, partner.longLivedToken);
        const updateParam = param[0];
        const entityManager = await this.getEntityManager();
        if (dto.brandExtraImage)
            dto.brandExtraImage = JSON.stringify(dto.brandExtraImage);
        await entityManager.update(brand_manager_entity_1.BrandManager, { brandNo: brand.brandNo }, Object.assign({}, dto));
        return this.findOne(brand.brandNo);
    }
    async update(dto) {
        const partner = await this.partnerService.findOne(dto.partnerSno);
        delete dto.partnerSno;
        const param = Object.assign({}, dto);
        const brand = await (0, gsUtil_1.shopByServerApi)(`/brands/${dto.brandNo}`, enum_1.HTTP_METHOD.GET, partner.systemKey, partner.longLivedToken);
        param['depth'] = brand.depth;
        param['no'] = dto.brandNo;
        const result = await (0, gsUtil_1.shopByServerApi)('/brands', enum_1.HTTP_METHOD.PUT, partner.systemKey, partner.longLivedToken, [param]);
        const entityManager = await this.getEntityManager();
        if (dto.brandExtraImage)
            dto.brandExtraImage = JSON.stringify(dto.brandExtraImage);
        await entityManager.update(brand_manager_entity_1.BrandManager, { brandNo: dto.brandNo }, Object.assign({}, dto));
        return this.findOne(dto.brandNo);
    }
    async findOne(brandNo, partnerSno) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager.createQueryBuilder(brand_manager_entity_1.BrandManager, 'brand');
        qb.leftJoinAndSelect('gs_partner', 'partner', 'brand.partnerSno=partner.sno')
            .select(['brand.*', 'partner.partnerName as partnerName'])
            .andWhere('brand.brandNo = :brandNo', { brandNo });
        if (partnerSno) {
            qb.andWhere('brand.partnerSno = :partnerSno', {
                partnerSno: partnerSno,
            });
        }
        const brandManager = await qb.getRawOne();
        if (!brandManager) {
            throw new common_1.HttpException('조회 결과가 없습니다.', common_1.HttpStatus.BAD_REQUEST);
        }
        brandManager.brandExtraImage = JSON.parse(brandManager.brandExtraImage);
        return brandManager;
    }
    async find(dto) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager.createQueryBuilder(brand_manager_entity_1.BrandManager, 'brand');
        qb.leftJoinAndSelect('gs_partner', 'partner', 'brand.partnerSno=partner.sno').select(['brand.*', 'partner.partnerName as partnerName']);
        if (dto.mainName) {
            qb.andWhere('brand.mainName like :mainName', {
                mainName: `%${dto.mainName}%`,
            });
        }
        if (dto.subName) {
            qb.andWhere('brand.subName like :subName', {
                subName: `%${dto.subName}%`,
            });
        }
        if (dto.description) {
            qb.andWhere('brand.description like :description', {
                description: `%${dto.description}%`,
            });
        }
        if (dto.partnerSno) {
            qb.andWhere('brand.partnerSno = :partnerSno', {
                partnerSno: dto.partnerSno,
            });
        }
        qb.offset(dto.skip);
        qb.limit(dto.take);
        qb.orderBy('brand.orderIndex', 'ASC');
        const list = await qb.getRawMany();
        const count = await qb.getCount();
        const data = [list, count];
        return (0, gsUtil_1.paginateResponse)(data, dto.page, dto.take);
    }
    async delete(dto) {
        const partner = await this.partnerService.findOne(dto.partnerSno);
        if (!partner.longLivedToken)
            throw new common_1.HttpException('인증토큰이 없습니다. 인증토큰을 먼저 발급하세요', common_1.HttpStatus.BAD_REQUEST);
        const param = {
            displayBrandNos: dto.displayBrandNos,
        };
        const result = await (0, gsUtil_1.shopByServerApi)('/brands', enum_1.HTTP_METHOD.DELETE, partner.systemKey, partner.longLivedToken, param);
        if (result.status === common_1.HttpStatus.NO_CONTENT) {
            const entityManager = await this.getEntityManager();
            entityManager
                .createQueryBuilder()
                .delete()
                .from(brand_manager_entity_1.BrandManager)
                .where('brandNo IN (:displayBrandNos)', {
                displayBrandNos: dto.displayBrandNos.split(',').map(Number),
            })
                .execute();
        }
        return {
            result: true,
        };
    }
    async sync(partnerSno, systemKey = null, longLivedToken = null) {
        if (!systemKey && !longLivedToken) {
            const partner = await this.partnerService.findOne(partnerSno);
            systemKey = partner.systemKey;
            longLivedToken = partner.longLivedToken;
        }
        const result = await (0, gsUtil_1.shopByServerApi)('/brands', enum_1.HTTP_METHOD.GET, systemKey, longLivedToken, null, '2.0');
        const entityManager = await this.getEntityManager();
        for (const brand of result) {
            await entityManager.save(brand_manager_entity_1.BrandManager, {
                partnerSno: partnerSno,
                brandNo: brand.no,
                mainName: brand.mainName,
                subName: brand.subName,
            });
        }
        return await entityManager
            .createQueryBuilder(brand_manager_entity_1.BrandManager, 'brand')
            .orderBy('regDt', 'DESC')
            .limit(1)
            .getOne();
    }
};
exports.BrandManagerService = BrandManagerService;
exports.BrandManagerService = BrandManagerService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [partner_service_1.PartnerService,
        core_1.ModuleRef])
], BrandManagerService);
//# sourceMappingURL=brand-manager.service.js.map