"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommentService = void 0;
const common_1 = require("@nestjs/common");
const default_service_1 = require("../../../common/service/default.service");
const comment_entity_1 = require("./entity/comment.entity");
const gsUtil_1 = require("../../../common/util/gsUtil");
const comment_update_dto_1 = require("./dto/comment.update.dto");
let CommentService = class CommentService extends default_service_1.DefaultService {
    async create(dto) {
        return super.createBase(comment_entity_1.Comment, dto);
    }
    async find(dto) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager
            .createQueryBuilder(comment_entity_1.Comment, 'comment')
            .select(['comment.*']);
        if (dto.partnerSno) {
            qb.andWhere('partnerSno = :partnerSno', {
                partnerSno: dto.partnerSno,
            });
        }
        if (dto.contentType) {
            qb.andWhere('contentType = :contentType', {
                contentType: dto.contentType,
            });
        }
        if (dto.contentSno) {
            qb.andWhere('contentSno = :contentSno', {
                contentSno: dto.contentSno,
            });
        }
        qb.offset(dto.skip);
        qb.limit(dto.take);
        qb.orderBy('IFNULL(parentSno, sno)', 'DESC');
        qb.addOrderBy('sno', 'ASC');
        const list = await qb.getRawMany();
        const count = await qb.getCount();
        const data = [list, count];
        return (0, gsUtil_1.paginateResponse)(data, dto.page, dto.take);
    }
    async update(dto) {
        const entityManager = await this.getEntityManager();
        const comment = await entityManager.findOneBy(comment_entity_1.Comment, {
            sno: dto.sno,
            partnerSno: dto.partnerSno,
        });
        if (!comment)
            throw new common_1.HttpException('데이터가 없습니다.', common_1.HttpStatus.BAD_REQUEST);
        if (comment.memberNo !== dto.memberNo)
            throw new common_1.HttpException('권한이 없습니다.', common_1.HttpStatus.UNAUTHORIZED);
        return await entityManager.update(comment_entity_1.Comment, { sno: dto.sno }, dto);
    }
    async deleteComment(sno, partnerSno, memberNo) {
        const entityManager = await this.getEntityManager();
        const comment = await entityManager.findOneBy(comment_entity_1.Comment, {
            sno: sno,
            partnerSno: partnerSno,
        });
        if (!comment)
            throw new common_1.HttpException('데이터가 없습니다.', common_1.HttpStatus.BAD_REQUEST);
        if (comment.memberNo !== memberNo)
            throw new common_1.HttpException('권한이 없습니다.', common_1.HttpStatus.UNAUTHORIZED);
        const dto = new comment_update_dto_1.CommentUpdateDto();
        dto.memberNo = -1;
        dto.memberId = '-';
        dto.comment = '삭제된 댓글입니다.';
        return await entityManager.update(comment_entity_1.Comment, { sno: sno }, dto);
    }
    async deleteCommentByAdmin(sno, partnerSno) {
        const entityManager = await this.getEntityManager();
        const comment = await entityManager.findOneBy(comment_entity_1.Comment, {
            sno: sno,
            partnerSno: partnerSno,
        });
        if (!comment)
            throw new common_1.HttpException('데이터가 없습니다.', common_1.HttpStatus.BAD_REQUEST);
        const dto = new comment_update_dto_1.CommentUpdateDto();
        dto.memberNo = -1;
        dto.memberId = '-';
        dto.comment = '관리자에 의해 삭제되었습니다.';
        return await entityManager.update(comment_entity_1.Comment, { sno: sno }, dto);
    }
};
exports.CommentService = CommentService;
exports.CommentService = CommentService = __decorate([
    (0, common_1.Injectable)()
], CommentService);
//# sourceMappingURL=comment.service.js.map