"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CurationCardService = void 0;
const common_1 = require("@nestjs/common");
const default_service_1 = require("../../../common/service/default.service");
const curation_product_display_entity_1 = require("./entity/curation-product-display.entity");
const curation_product_entity_1 = require("./entity/curation-product.entity");
const curation_entity_1 = require("./entity/curation.entity");
const gsUtil_1 = require("../../../common/util/gsUtil");
const typeorm_1 = require("typeorm");
let CurationCardService = class CurationCardService extends default_service_1.DefaultService {
    async create(dto) {
        const entityManager = await this.getEntityManager();
        const curation = await entityManager.transaction(async (transactionalEntityManager) => {
            const curation = new curation_entity_1.Curation();
            curation.groupId = dto.groupId;
            curation.title = dto.title;
            curation.description = dto.description;
            curation.displayOrder = dto.displayOrder;
            curation.displayFl = dto.displayFl;
            curation.displayType = dto.displayType;
            curation.startDt = dto.startDt;
            curation.endDt = dto.endDt;
            curation.pcImgUrl = dto.thumbnail.pcImgUrl;
            curation.mobileImgUrl = dto.thumbnail.mobileImgUrl;
            curation.landingUrl = dto.landingUrl;
            curation.blankFl = dto.blankFl;
            curation.tagName = dto.tag.tagName;
            curation.tagColor = dto.tag.tagColor;
            curation.productDisplayType = dto.productDisplayType;
            curation.additionalInfo = dto.additionalInfo;
            curation.partnerSno = dto.partnerSno;
            const curationSno = await transactionalEntityManager.save(curation);
            const productDisplayList = [];
            for (const productDisplayDto of dto.productDisplay) {
                const productDisplay = new curation_product_display_entity_1.CurationProductDisplay();
                productDisplay.curationSno = curationSno.sno;
                productDisplay.displayTitle = productDisplayDto.displayTitle;
                const displaySno = await transactionalEntityManager.save(productDisplay);
                const productList = [];
                for (const productNo of productDisplayDto.productList) {
                    const product = new curation_product_entity_1.CurationProduct();
                    product.productNo = productNo;
                    product.productDisplaySno = displaySno.sno;
                    productList.push(product);
                }
                if (productList.length > 0) {
                    await transactionalEntityManager.save(productList);
                }
                productDisplay.products = productList;
                productDisplayList.push(productDisplay);
                curation.productDisplay = productDisplayList;
            }
            return curation;
        });
        return curation;
    }
    async update(dto) {
        const entityManager = await this.getEntityManager();
        const curation = await entityManager.transaction(async (transactionalEntityManager) => {
            const curation = new curation_entity_1.Curation();
            curation.sno = dto.sno;
            curation.groupId = dto.groupId;
            curation.title = dto.title;
            curation.description = dto.description;
            curation.displayOrder = dto.displayOrder;
            curation.displayFl = dto.displayFl;
            curation.displayType = dto.displayType;
            curation.startDt = dto.startDt;
            curation.endDt = dto.endDt;
            curation.pcImgUrl = dto.thumbnail.pcImgUrl;
            curation.mobileImgUrl = dto.thumbnail.mobileImgUrl;
            curation.landingUrl = dto.landingUrl;
            curation.blankFl = dto.blankFl;
            curation.tagName = dto.tag.tagName;
            curation.tagColor = dto.tag.tagColor;
            curation.productDisplayType = dto.productDisplayType;
            curation.additionalInfo = dto.additionalInfo;
            await transactionalEntityManager.save(curation);
            const productDisplayList = await entityManager.findBy(curation_product_display_entity_1.CurationProductDisplay, { curationSno: dto.sno });
            if (productDisplayList.length > 0) {
                const productDisplaySnos = productDisplayList.map((productDisplay) => productDisplay.sno);
                await entityManager.delete(curation_product_entity_1.CurationProduct, {
                    productDisplaySno: (0, typeorm_1.In)(productDisplaySnos),
                });
                await entityManager.delete(curation_product_display_entity_1.CurationProductDisplay, productDisplaySnos);
            }
            const displayList = [];
            for (const productDisplayDto of dto.productDisplay) {
                const productDisplay = new curation_product_display_entity_1.CurationProductDisplay();
                productDisplay.curationSno = dto.sno;
                productDisplay.displayTitle = productDisplayDto.displayTitle;
                const displaySno = await transactionalEntityManager.save(productDisplay);
                const productList = [];
                for (const productNo of productDisplayDto.productList) {
                    const product = new curation_product_entity_1.CurationProduct();
                    product.productNo = productNo;
                    product.productDisplaySno = displaySno.sno;
                    productList.push(product);
                }
                if (productList.length > 0) {
                    await transactionalEntityManager.save(productList);
                }
            }
        });
        return curation;
    }
    async getCurationListByGroupId(groupId, partnerSno, isAdmin = false) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager.createQueryBuilder(curation_entity_1.Curation, 'curation');
        qb.where('curation.groupId = :groupId', { groupId });
        qb.andWhere('partnerSno = :partnerSno', { partnerSno });
        qb.select([
            'curation.sno',
            'curation.title',
            'curation.description',
            'curation.groupId',
            'curation.productDisplayType',
            'curation.displayFl',
            'curation.displayType',
            'curation.startDt',
            'curation.endDt',
            'curation.pcImgUrl',
            'curation.mobileImgUrl',
            'curation.landingUrl',
            'curation.blankFl',
            'curation.tagName',
            'curation.tagColor',
            'curation.additionalInfo',
            'curation.displayOrder',
        ]);
        qb.leftJoinAndSelect('curation.productDisplay', 'productDisplay');
        qb.leftJoinAndSelect('productDisplay.products', 'products');
        qb.orderBy('curation.displayOrder', 'ASC');
        qb.addOrderBy('products.sno', 'ASC');
        if (!isAdmin)
            qb.andWhere('curation.displayFl = true');
        qb.andWhere(`(curation.displayType = 'ALWAYS' OR (displayType='PERIOD' AND CURDATE() BETWEEN startDt AND endDt ))`);
        const curationList = await qb.getMany();
        return curationList;
    }
    async getCurationList(dto) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager.createQueryBuilder(curation_entity_1.Curation, 'curation');
        if (dto.groupId)
            qb.where('curation.groupId = :groupId', { groupId: dto.groupId });
        if (dto.displayFl !== undefined)
            qb.andWhere('curation.displayFl = :displayFl', {
                displayFl: dto.displayFl,
            });
        if (dto.productDisplayType)
            qb.andWhere('curation.productDisplayType = :productDisplayType', {
                productDisplayType: dto.productDisplayType,
            });
        qb.andWhere('partnerSno = :partnerSno', { partnerSno: dto.partnerSno });
        qb.select(['curation.*']);
        qb.orderBy('curation.sno', 'DESC');
        qb.offset(dto.skip);
        qb.limit(dto.take);
        const list = await qb.getRawMany();
        const count = await qb.getCount();
        const data = [list, count];
        return (0, gsUtil_1.paginateResponse)(data, dto.page, dto.take);
    }
    async deleteCuration(sno) {
        const entityManager = await this.getEntityManager();
        await entityManager.transaction(async (transactionalEntityManager) => {
            const productDisplayList = await entityManager.findBy(curation_product_display_entity_1.CurationProductDisplay, { curationSno: sno });
            const productDisplaySnos = productDisplayList.map((productDisplay) => productDisplay.sno);
            await transactionalEntityManager.delete(curation_product_entity_1.CurationProduct, {
                productDisplaySno: (0, typeorm_1.In)(productDisplaySnos),
            });
            await transactionalEntityManager.delete(curation_product_display_entity_1.CurationProductDisplay, {
                curationSno: sno,
            });
            await transactionalEntityManager.delete(curation_entity_1.Curation, { sno });
        });
    }
    async getCuration(sno, partnerSno) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager.createQueryBuilder(curation_entity_1.Curation, 'curation');
        qb.where('curation.sno = :sno', { sno });
        qb.andWhere('partnerSno = :partnerSno', { partnerSno });
        qb.select([
            'curation.sno',
            'curation.title',
            'curation.description',
            'curation.groupId',
            'curation.productDisplayType',
            'curation.displayFl',
            'curation.displayType',
            'curation.startDt',
            'curation.endDt',
            'curation.pcImgUrl',
            'curation.mobileImgUrl',
            'curation.landingUrl',
            'curation.blankFl',
            'curation.tagName',
            'curation.tagColor',
            'curation.additionalInfo',
            'curation.displayOrder',
        ]);
        qb.leftJoinAndSelect('curation.productDisplay', 'productDisplay');
        qb.leftJoinAndSelect('productDisplay.products', 'products');
        qb.orderBy('curation.displayOrder', 'ASC');
        qb.addOrderBy('products.sno', 'ASC');
        const curation = await qb.getOne();
        return curation;
    }
};
exports.CurationCardService = CurationCardService;
exports.CurationCardService = CurationCardService = __decorate([
    (0, common_1.Injectable)()
], CurationCardService);
//# sourceMappingURL=curation-card.service.js.map