"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MagazineAdminController = void 0;
const common_1 = require("@nestjs/common");
const magazine_service_1 = require("./magazine.service");
const accessToken_guard_1 = require("../../../common/guards/accessToken.guard");
const hasRole_decorator_1 = require("../../../common/decorators/hasRole.decorator");
const enum_1 = require("../../../common/enum/enum");
const roles_guard_1 = require("../../../common/guards/roles.guard");
const swagger_1 = require("@nestjs/swagger");
const magazine_insert_dto_1 = require("./dto/magazine.insert.dto");
const magazine_admin_search_dto_1 = require("./dto/magazine.admin.search.dto");
const magazine_update_dto_1 = require("./dto/magazine.update.dto");
const magazine_entity_1 = require("./entity/magazine.entity");
let MagazineAdminController = class MagazineAdminController {
    constructor(magazineService) {
        this.magazineService = magazineService;
    }
    async create(req, dto) {
        dto.partnerSno = req.partnerSno;
        dto.managerSno = req.sno;
        return await this.magazineService.create(dto);
    }
    async findForAdmin(req, dto) {
        if (req.managerType === enum_1.MANAGER_TYPE.PARTNER)
            dto.partnerSno = req.partnerSno;
        return await this.magazineService.findForAdmin(dto);
    }
    async findOneForAdmin(req, sno) {
        let partnerSno = null;
        if (req.managerType === enum_1.MANAGER_TYPE.PARTNER)
            partnerSno = req.partnerSno;
        return await this.magazineService.findOneForAdmin(sno, partnerSno);
    }
    async update(req, dto) {
        dto.managerSno = req.sno;
        dto.partnerSno = req.partnerSno;
        if (req.managerType === enum_1.MANAGER_TYPE.ADMIN)
            dto.managerSno = 0;
        return await this.magazineService.update(dto);
    }
    async delete(req, sno) {
        return await this.magazineService.deleteMagazine(req.partnerSno, req.sno, sno);
    }
};
exports.MagazineAdminController = MagazineAdminController;
__decorate([
    (0, common_1.Post)(),
    (0, hasRole_decorator_1.HasRoles)(enum_1.MANAGER_TYPE.PARTNER),
    (0, common_1.UseGuards)(accessToken_guard_1.AccessTokenGuard, roles_guard_1.RolesGuard),
    (0, swagger_1.ApiHeader)({
        name: 'access token',
        required: true,
        description: '관리자 access token',
    }),
    (0, swagger_1.ApiOperation)({ summary: '매거진 등록' }),
    (0, swagger_1.ApiQuery)({ type: magazine_insert_dto_1.MagazineInsertDto }),
    (0, swagger_1.ApiCreatedResponse)({ description: '등록성공', type: magazine_entity_1.Magazine }),
    __param(0, (0, common_1.Req)()),
    __param(1, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, magazine_insert_dto_1.MagazineInsertDto]),
    __metadata("design:returntype", Promise)
], MagazineAdminController.prototype, "create", null);
__decorate([
    (0, common_1.Get)(),
    (0, hasRole_decorator_1.HasRoles)(enum_1.MANAGER_TYPE.PARTNER),
    (0, common_1.UseGuards)(accessToken_guard_1.AccessTokenGuard, roles_guard_1.RolesGuard),
    (0, swagger_1.ApiResponse)({ status: 200, type: [magazine_entity_1.Magazine] }),
    (0, swagger_1.ApiOperation)({ summary: '매거진 목록 검색' }),
    __param(0, (0, common_1.Req)()),
    __param(1, (0, common_1.Query)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, magazine_admin_search_dto_1.MagazineAdminSearchDto]),
    __metadata("design:returntype", Promise)
], MagazineAdminController.prototype, "findForAdmin", null);
__decorate([
    (0, common_1.Get)('/:sno'),
    (0, hasRole_decorator_1.HasRoles)(enum_1.MANAGER_TYPE.PARTNER),
    (0, common_1.UseGuards)(accessToken_guard_1.AccessTokenGuard, roles_guard_1.RolesGuard),
    (0, swagger_1.ApiOperation)({ summary: '매거진 조회' }),
    (0, swagger_1.ApiResponse)({ status: 200, type: magazine_entity_1.Magazine }),
    __param(0, (0, common_1.Req)()),
    __param(1, (0, common_1.Param)('sno')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Number]),
    __metadata("design:returntype", Promise)
], MagazineAdminController.prototype, "findOneForAdmin", null);
__decorate([
    (0, common_1.Put)(),
    (0, hasRole_decorator_1.HasRoles)(enum_1.MANAGER_TYPE.PARTNER),
    (0, common_1.UseGuards)(accessToken_guard_1.AccessTokenGuard, roles_guard_1.RolesGuard),
    (0, swagger_1.ApiOperation)({ summary: '매거진 수정' }),
    (0, swagger_1.ApiQuery)({ type: magazine_update_dto_1.MagazineUpdateDto }),
    (0, swagger_1.ApiResponse)({ status: 200, type: magazine_entity_1.Magazine }),
    __param(0, (0, common_1.Req)()),
    __param(1, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, magazine_update_dto_1.MagazineUpdateDto]),
    __metadata("design:returntype", Promise)
], MagazineAdminController.prototype, "update", null);
__decorate([
    (0, common_1.Delete)(':sno'),
    (0, hasRole_decorator_1.HasRoles)(enum_1.MANAGER_TYPE.PARTNER),
    (0, common_1.UseGuards)(accessToken_guard_1.AccessTokenGuard, roles_guard_1.RolesGuard),
    (0, swagger_1.ApiOperation)({ summary: '매거진 삭제' }),
    __param(0, (0, common_1.Req)()),
    __param(1, (0, common_1.Param)('sno')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Number]),
    __metadata("design:returntype", Promise)
], MagazineAdminController.prototype, "delete", null);
exports.MagazineAdminController = MagazineAdminController = __decorate([
    (0, swagger_1.ApiTags)('[관리자] 매거진'),
    (0, common_1.Controller)('/app/admin/magazine'),
    __metadata("design:paramtypes", [magazine_service_1.MagazineService])
], MagazineAdminController);
//# sourceMappingURL=magazine.admin.controller.js.map