"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SearchRankingService = void 0;
const common_1 = require("@nestjs/common");
const core_1 = require("@nestjs/core");
const ioredis_1 = __importDefault(require("ioredis"));
const search_ranking_entity_1 = require("./entity/search-ranking.entity");
const default_service_1 = require("../../../common/service/default.service");
const moment_1 = __importDefault(require("moment"));
const keyword_blacklist_entity_1 = require("./entity/keyword-blacklist.entity");
let SearchRankingService = class SearchRankingService extends default_service_1.DefaultService {
    constructor(moduleRef) {
        super(moduleRef);
        this.moduleRef = moduleRef;
        this.redis = new ioredis_1.default({
            host: process.env.REDIS_HOST,
            port: Number(process.env.REDIS_PORT),
        });
    }
    async snapshotCurrentRanking(partnerSno) {
        const timestamp = (0, moment_1.default)().format('YYYYMMDDHH');
        const hour = (0, moment_1.default)().format('HH');
        if (hour === '00')
            await this.resetDailyRanking(partnerSno);
        const snapshotKey = `search_rankings_snapshot:${partnerSno}:${timestamp}`;
        const rankings = await this.redis.zrevrange(`search_ranking:${partnerSno}`, 0, -1, 'WITHSCORES');
        for (let i = 0; i < rankings.length; i += 2) {
            await this.redis.zadd(snapshotKey, Number(rankings[i + 1]), rankings[i]);
        }
        await this.redis.expire(snapshotKey, 24 * 60 * 60);
    }
    async isDuplicateSearch(partnerSno, ip, keyword, expireTime = 3600) {
        const key = `search:${partnerSno}:${keyword}:ip:${ip}`;
        const exists = await this.redis.exists(key);
        if (exists) {
            return true;
        }
        else {
            await this.redis.set(key, '1', 'EX', expireTime);
            return false;
        }
    }
    async incrementKeyword(partnerSno, ip, keyword) {
        keyword = keyword.toLowerCase();
        if (!(await this.isBlacklisted(keyword))) {
            if (!(await this.isDuplicateSearch(partnerSno, ip, keyword))) {
                await this.redis.zincrby(`search_ranking:${partnerSno}`, 1, keyword);
                const entityManager = await this.getEntityManager();
                const searchDt = (0, moment_1.default)().format('YYYYMMDD');
                await entityManager.query(`
        INSERT INTO gs_searchRanking (partnerSno, keyword, count, searchDt)
        VALUES (?, ?, 1, ?)
        ON DUPLICATE KEY UPDATE count = count + 1
        `, [partnerSno, keyword, searchDt]);
            }
        }
    }
    async isBlacklisted(keyword) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager.createQueryBuilder(keyword_blacklist_entity_1.KeywordBlacklist, 'black');
        qb.andWhere('black.keyword Like :keyword', {
            keyword: `%${keyword}%`,
        });
        const isBlacked = await qb.getMany();
        if (isBlacked.length > 0)
            return true;
        return false;
    }
    async getKeywordRanking(partnerSno, count = 10) {
        const currentRankings = await this.getCurrentRanking(partnerSno, count);
        const previousHour = (0, moment_1.default)().subtract(1, 'hour').format('YYYYMMDDHH');
        const previousSnapshotKey = `search_rankings_snapshot:${partnerSno}:${previousHour}`;
        const previousRankings = await this.redis.zrevrange(previousSnapshotKey, 0, count - 1, 'WITHSCORES');
        const previousRankMap = new Map();
        for (let i = 0; i < previousRankings.length; i += 2) {
            previousRankMap.set(previousRankings[i], i / 2 + 1);
        }
        const topKeywords = [];
        let ranking = 1;
        for (let i = 0; i < currentRankings.length; i += 2) {
            const keyword = currentRankings[i];
            const score = Number(currentRankings[i + 1]);
            const currentRank = i / 2 + 1;
            const previousRank = previousRankMap.get(keyword);
            const change = previousRank !== undefined ? previousRank - currentRank : null;
            topKeywords.push({ ranking, keyword, score, change });
            ranking++;
        }
        return topKeywords;
    }
    async resetDailyRanking(partnerSno) {
        this.redis.del(`search_ranking:${partnerSno}`);
    }
    async getAllSnapshots(partnerSno) {
        const snapshotPattern = `search_rankings_snapshot:${partnerSno}:*`;
        const snapshotKeys = await this.redis.keys(snapshotPattern);
        const allSnapshots = [];
        for (const key of snapshotKeys) {
            const timestamp = key.split(':')[2];
            const rankings = await this.redis.zrevrange(key, 0, -1, 'WITHSCORES');
            const snapshotRankings = [];
            for (let i = 0; i < rankings.length; i += 2) {
                snapshotRankings.push({
                    keyword: rankings[i],
                    score: Number(rankings[i + 1]),
                });
            }
            allSnapshots.push({
                timestamp,
                rankings: snapshotRankings,
            });
        }
        return allSnapshots;
    }
    async getCurrentRanking(partnerSno, count = 10) {
        let currentRankings = await this.redis.zrevrange(`search_ranking:${partnerSno}`, 0, count - 1, 'WITHSCORES');
        if (currentRankings.length < count) {
            const entityManager = await this.getEntityManager();
            const searchDt = (0, moment_1.default)().subtract(1, 'day').format('YYYYMMDD');
            const list = await entityManager.find(search_ranking_entity_1.SearchRanking, {
                where: { partnerSno: partnerSno, searchDt: searchDt },
                order: { count: 'DESC' },
                take: count,
            });
            for (const ranking of list) {
                await this.redis.zadd(`search_ranking:${partnerSno}`, ranking.count, ranking.keyword);
            }
            currentRankings = await this.redis.zrevrange(`search_ranking:${partnerSno}`, 0, count - 1, 'WITHSCORES');
        }
        return currentRankings;
    }
};
exports.SearchRankingService = SearchRankingService;
exports.SearchRankingService = SearchRankingService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [core_1.ModuleRef])
], SearchRankingService);
//# sourceMappingURL=search-ranking.service.js.map