"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SurveyService = void 0;
const common_1 = require("@nestjs/common");
const survey_entity_1 = require("./entity/survey.entity");
const survey_question_entity_1 = require("./entity/survey-question.entity");
const survey_result_entity_1 = require("./entity/survey-result.entity");
const default_service_1 = require("../../../common/service/default.service");
let SurveyService = class SurveyService extends default_service_1.DefaultService {
    async getSurvey(partnerSno, surveySno) {
        const entityManager = await this.getEntityManager();
        const survey = await entityManager.findOneBy(survey_entity_1.Survey, { sno: surveySno });
        if (!survey)
            throw new common_1.HttpException('데이터가 없습니다1.', common_1.HttpStatus.BAD_REQUEST);
        if (survey.partnerSno != partnerSno)
            throw new common_1.HttpException('데이터가 없습니다2.', common_1.HttpStatus.BAD_REQUEST);
        return survey;
    }
    async getSurveyQuestion(partnerSno, surveySno, memberNo) {
        await this.validateSurvey(partnerSno, surveySno, memberNo);
        const entityManager = await this.getEntityManager();
        const questions = await entityManager
            .createQueryBuilder(survey_question_entity_1.SurveyQuestion, 'question')
            .leftJoin('question.template', 'template')
            .leftJoin('question.answers', 'answer')
            .select([
            'question.sno',
            'question.title',
            'question.require',
            'question.isEtc',
            'question.preference',
            'template.templateTitle',
            'template.templateCode',
            'answer',
        ])
            .where('question.surveySno=:surveySno', { surveySno })
            .orderBy('question.sno, answer.sno', 'ASC')
            .getMany();
        return questions;
    }
    async saveSurveyResult(dto) {
        try {
            await this.validateSurvey(dto.partnerSno, dto.surveySno, dto.memberNo);
            for (const answer of dto.userAnswer) {
                await super.createBase(survey_result_entity_1.SurveyResult, {
                    surveySno: dto.surveySno,
                    memberNo: dto.memberNo,
                    memberId: dto.memberId,
                    questionSno: answer.questionSno,
                    answerSno: answer.answerSno,
                    answerText: answer.answerText,
                });
            }
            return { status: 200, message: '참여완료' };
        }
        catch (error) {
            throw error;
        }
    }
    async validateSurvey(partnerSno, surveySno, memberNo) {
        const entityManager = await this.getEntityManager();
        const survey = await this.getSurvey(partnerSno, surveySno);
        if (survey.memberFl === true && !memberNo)
            throw new common_1.HttpException('로그인 후 참여하세요.', common_1.HttpStatus.BAD_REQUEST);
        const surveyFl = await entityManager.findBy(survey_result_entity_1.SurveyResult, {
            surveySno: surveySno,
            memberNo: memberNo,
        });
        if (surveyFl.length > 0)
            throw new common_1.HttpException('설문조사에 이미 참여했습니다.', common_1.HttpStatus.BAD_REQUEST);
    }
};
exports.SurveyService = SurveyService;
exports.SurveyService = SurveyService = __decorate([
    (0, common_1.Injectable)()
], SurveyService);
//# sourceMappingURL=survey.service.js.map