"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthService = void 0;
const common_1 = require("@nestjs/common");
const jwt_1 = require("@nestjs/jwt");
const default_service_1 = require("../../../common/service/default.service");
const core_1 = require("@nestjs/core");
const manager_service_1 = require("../../admin/manager/manager.service");
const config_1 = require("@nestjs/config");
const bcrypt_1 = require("bcrypt");
const enum_1 = require("../../../common/enum/enum");
let AuthService = class AuthService extends default_service_1.DefaultService {
    constructor(moduleRef, managerService, jwtService, configService) {
        super(moduleRef);
        this.managerService = managerService;
        this.jwtService = jwtService;
        this.configService = configService;
    }
    async signIn(auth) {
        const manager = await this.managerService.findOneById(auth.id);
        if (!manager)
            throw new common_1.HttpException('아이디 또는 비밀번호를 확인하세요.', common_1.HttpStatus.BAD_REQUEST);
        const pwdMatch = await (0, bcrypt_1.compare)(auth.pwd, manager.pwd);
        if (!pwdMatch)
            throw new common_1.HttpException('아이디 또는 비밀번호를 확인하세요.', common_1.HttpStatus.BAD_REQUEST);
        if (manager.status == enum_1.YN.N)
            throw new common_1.HttpException('관리자 미승인 상태입니다. 관리자에게 문의하세요', common_1.HttpStatus.BAD_REQUEST);
        const tokens = await this.getTokens(manager);
        this.managerService.update({
            sno: manager.sno,
            accessToken: tokens.accessToken,
        });
        return tokens;
    }
    async logOut(managerSno) {
        await this.managerService.update({
            sno: managerSno,
            accessToken: null,
        });
        return true;
    }
    async getTokens(manager) {
        const managerName = manager.managerName;
        const managerType = manager.managerType;
        const managerId = manager.id;
        const partnerSno = manager.partnerSno;
        const managerEmail = manager.managerEmail;
        const managerTel = manager.managerTel;
        const authority = manager.authority;
        const [accessToken, refreshToken] = await Promise.all([
            this.jwtService.signAsync({
                sno: manager.sno,
                managerName: managerName,
                managerId: managerId,
                managerType: managerType,
                partnerSno: partnerSno,
                managerEmail: managerEmail,
                managerTel: managerTel,
                authority: authority,
            }, {
                secret: this.configService.get('JWT_ACCESS_SECRET'),
                expiresIn: '100000d',
            }),
            this.jwtService.signAsync({
                sno: manager.sno,
                managerName: managerName,
                managerId: managerId,
                managerType: managerType,
                partnerSno: partnerSno,
                managerEmail: managerEmail,
                managerTel: managerTel,
                authority: authority,
            }, {
                secret: this.configService.get('JWT_REFRESH_SECRET'),
                expiresIn: '7d',
            }),
        ]);
        return {
            accessToken,
            refreshToken,
            managerName,
            managerId,
            managerType,
            partnerSno,
            managerEmail,
            managerTel,
            authority,
        };
    }
    async getAppToken(partnerSno) {
        const [appToken] = await Promise.all([
            this.jwtService.signAsync({ partnerSno: partnerSno, managerType: enum_1.MANAGER_TYPE.PARTNER }, {
                secret: this.configService.get('JWT_ACCESS_SECRET'),
                expiresIn: '100000d',
            }),
        ]);
        return appToken;
    }
    async decryptToken(token) {
        const bearerToken = token.toString().replace('Bearer', '').trim();
        const payload = this.jwtService.verify(bearerToken, {
            secret: process.env.JWT_ACCESS_SECRET,
        });
        return payload;
    }
};
exports.AuthService = AuthService;
exports.AuthService = AuthService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [core_1.ModuleRef,
        manager_service_1.ManagerService,
        jwt_1.JwtService,
        config_1.ConfigService])
], AuthService);
//# sourceMappingURL=auth.service.js.map