"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.multerOptionsFactory = void 0;
const multer_s3_1 = __importDefault(require("multer-s3"));
const client_s3_1 = require("@aws-sdk/client-s3");
const path_1 = __importDefault(require("path"));
const moment_1 = __importDefault(require("moment"));
const gsUtil_1 = require("../../../common/util/gsUtil");
const multerOptionsFactory = () => {
    const s3 = new client_s3_1.S3Client({
        region: process.env.AWS_REGION,
        credentials: {
            accessKeyId: process.env.AWS_API_ACCESS_KEY,
            secretAccessKey: process.env.AWS_API_SECRET_KEY,
        },
    });
    const currentDate = (0, moment_1.default)().format('YYYYMMDD');
    return {
        storage: (0, multer_s3_1.default)({
            s3,
            bucket: process.env.AWS_BUCKET,
            key(_req, file, done) {
                const ext = path_1.default.extname(file.originalname);
                const basename = path_1.default.basename(file.originalname, ext);
                done(null, `${currentDate}/${Date.now()}_` + (0, gsUtil_1.randomDigitNumber)());
            },
            acl: 'public-read',
            contentType: multer_s3_1.default.AUTO_CONTENT_TYPE,
        }),
        limits: { fileSize: 10 * 1024 * 1024 },
    };
};
exports.multerOptionsFactory = multerOptionsFactory;
//# sourceMappingURL=multer.options.js.map