"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GlobalExceptionFilter = void 0;
const common_1 = require("@nestjs/common");
const jwt_1 = require("@nestjs/jwt");
const exception_service_1 = require("../../api/common/exception/exception.service");
const typeorm_1 = require("typeorm");
const date_fns_1 = require("date-fns");
let GlobalExceptionFilter = class GlobalExceptionFilter {
    constructor(gsExceptionService, jwtService) {
        this.gsExceptionService = gsExceptionService;
        this.jwtService = jwtService;
    }
    async catch(exception, host) {
        var _a, _b, _c;
        if (exception.constructor === common_1.NotFoundException)
            return;
        const ctx = host.switchToHttp();
        const stack = exception.stack;
        const response = ctx.getResponse();
        const request = ctx.getRequest();
        const ip = ((_a = request.headers['x-forwarded-for']) === null || _a === void 0 ? void 0 : _a.toString().split(',')[0]) ||
            request.socket.remoteAddress;
        const { authorization } = request.headers;
        let partnerSno = 0;
        if (authorization != null) {
            const accessToken = authorization.split(' ')[1];
            const decodeToken = this.jwtService.decode(accessToken, {
                complete: false,
                json: true,
            });
            partnerSno = (_b = decodeToken === null || decodeToken === void 0 ? void 0 : decodeToken.partnerSno) !== null && _b !== void 0 ? _b : 0;
        }
        let status = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
        let message = exception.message.message;
        let code = 'HttpException';
        switch (exception.constructor) {
            case common_1.HttpException:
                status = exception.getStatus();
                message = exception.message;
                break;
            case typeorm_1.QueryFailedError:
                status = common_1.HttpStatus.UNPROCESSABLE_ENTITY;
                message = exception.message;
                code = exception.code;
                break;
            case typeorm_1.EntityNotFoundError:
                status = common_1.HttpStatus.UNPROCESSABLE_ENTITY;
                message = exception.message;
                code = exception.code;
                break;
            case typeorm_1.CannotCreateEntityIdMapError:
                status = common_1.HttpStatus.UNPROCESSABLE_ENTITY;
                message = exception.message;
                code = exception.code;
                break;
            case common_1.UnauthorizedException:
                status = common_1.HttpStatus.UNAUTHORIZED;
                message = 'Unauthorized';
                break;
            case TypeError:
                status = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
                message = exception.message;
                code = exception.code;
                break;
            default:
                status = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
                message = exception;
        }
        if (typeof message === 'object')
            message = JSON.stringify(message);
        if (typeof message === 'object' &&
            (message['response']['statusCode'] === 404 ||
                message['response']['statusCode'] === '404')) {
            response.status(status).json({
                statusCode: 404,
                message: message || 'Internal server error',
                timestamp: (0, date_fns_1.format)(new Date(), 'yyyy/M/d, h:mm:ss a'),
                path: request.url,
            });
        }
        await this.gsExceptionService.create({
            partnerSno: partnerSno,
            url: request.url,
            request: JSON.stringify(request.body),
            message: message,
            trace: stack.toString(),
            errorCode: status.toString(),
            ip,
        });
        await response.status(status).json({
            statusCode: status,
            code: (_c = exception.response) === null || _c === void 0 ? void 0 : _c.code,
            message: message || 'Internal server error',
            trace: stack.toString(),
            timestamp: (0, date_fns_1.format)(new Date(), 'yyyy/M/d, h:mm:ss a'),
            path: request.url,
        });
    }
};
exports.GlobalExceptionFilter = GlobalExceptionFilter;
exports.GlobalExceptionFilter = GlobalExceptionFilter = __decorate([
    (0, common_1.Catch)(),
    __metadata("design:paramtypes", [exception_service_1.GSExceptionService,
        jwt_1.JwtService])
], GlobalExceptionFilter);
//# sourceMappingURL=GlobalExceptionFilter.js.map