"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isNullOrEmpty = exports.convertDeliveryType = exports.convertNumberFormat = exports.tossBankCodeToBankName = exports.getRandomString = exports.formatDateToyyyyMMdd = exports.getAlphabetByNumber = exports.getUUID = exports.getEventTime = exports.getDatesStartToLast = exports.convertGlobalTelNo = exports.shopByShopApi = exports.shopByServerApi = exports.randomDigitNumber = exports.paginateResponse = void 0;
const axios_1 = __importDefault(require("axios"));
const enum_1 = require("../enum/enum");
const common_1 = require("@nestjs/common");
const uuid_1 = require("uuid");
function paginateResponse(data, page, limit) {
    const [result, total] = data;
    const lastPage = Math.ceil(total / limit);
    const nextPage = page + 1 > lastPage ? null : page + 1;
    const prevPage = page - 1 < 1 ? null : page - 1;
    return {
        statusCode: 'success',
        data: [...result],
        count: total,
        currentPage: page,
        nextPage: nextPage,
        prevPage: prevPage,
        lastPage: lastPage,
    };
}
exports.paginateResponse = paginateResponse;
function randomDigitNumber() {
    const min = 1000000;
    const max = 9999999;
    const randomNumber = Math.floor(Math.random() * (max - min + 1)) + min;
    return randomNumber.toString();
}
exports.randomDigitNumber = randomDigitNumber;
async function shopByServerApi(apiUrl, httpMethod, systemKey, longLivedToken, params, version = '1.0') {
    if (!apiUrl.startsWith('/'))
        apiUrl = '/' + apiUrl;
    const headers = {
        systemKey: systemKey,
        Authorization: `Bearer ${longLivedToken}`,
        version: version,
    };
    const api = process.env.SHOPBY_SERVER_API_HOST + apiUrl;
    if (httpMethod == enum_1.HTTP_METHOD.GET) {
        return await GET_shopByServerApi(api, headers, params);
    }
    else if (httpMethod == enum_1.HTTP_METHOD.POST) {
        return await POST_shopByServerApi(api, headers, params);
    }
    else if (httpMethod == enum_1.HTTP_METHOD.PATCH) {
        return await PATCH_shopByServerApi(api, headers, params);
    }
    else if (httpMethod == enum_1.HTTP_METHOD.PUT) {
        return await PUT_shopByServerApi(api, headers, params);
    }
    else if (httpMethod == enum_1.HTTP_METHOD.DELETE) {
        return await DELETE_shopByServerApi(api, headers, params);
    }
}
exports.shopByServerApi = shopByServerApi;
async function shopByShopApi(apiUrl, httpMethod, clientid, params, version = '1.0', platform = 'PC', accessToken, shopByAuthorization) {
    if (!apiUrl.startsWith('/'))
        apiUrl = '/' + apiUrl;
    const headers = {
        clientid: clientid,
        version: version,
        platform: platform,
        'Content-Type': 'application/json',
    };
    if (accessToken)
        headers['accessToken'] = accessToken;
    if (shopByAuthorization)
        headers['Shop-By-Authorization'] = shopByAuthorization;
    const api = process.env.SHOPBY_SHOP_API_HOST + apiUrl;
    if (httpMethod == enum_1.HTTP_METHOD.GET) {
        return await GET_shopByServerApi(api, headers, params);
    }
    else if (httpMethod == enum_1.HTTP_METHOD.POST) {
        return await POST_shopByServerApi(api, headers, params);
    }
    else if (httpMethod == enum_1.HTTP_METHOD.PATCH) {
        return await PATCH_shopByServerApi(api, headers, params);
    }
    else if (httpMethod == enum_1.HTTP_METHOD.PUT) {
        return await PUT_shopByServerApi(api, headers, params);
    }
    else if (httpMethod == enum_1.HTTP_METHOD.DELETE) {
        return await DELETE_shopByServerApi(api, headers, params);
    }
}
exports.shopByShopApi = shopByShopApi;
async function GET_shopByServerApi(api, headers, params) {
    try {
        const response = await axios_1.default.get(api, {
            headers: headers,
            params: params,
        });
        return response.data;
    }
    catch (error) {
        throw new common_1.HttpException(error.response.data.message, error.response.data.status);
    }
}
async function POST_shopByServerApi(api, headers, params) {
    const response = await axios_1.default
        .post(api, params, {
        headers: headers,
    })
        .catch(function (error) {
        throw new common_1.HttpException({
            message: error.response.data.message,
            code: error.response.data.code,
        }, error.response.data.status);
    });
    return response.data;
}
async function PUT_shopByServerApi(api, headers, params) {
    const response = await axios_1.default
        .put(api, params, {
        headers: headers,
    })
        .catch(function (error) {
        throw new common_1.HttpException({
            message: error.response.data.message,
            code: error.response.data.code,
        }, error.response.data.status);
    });
    return response.data;
}
async function DELETE_shopByServerApi(api, headers, params) {
    const response = await axios_1.default
        .delete(api, {
        headers: headers,
        params: params,
    })
        .catch(function (error) {
        throw new common_1.HttpException(error.response.data.result.message, error.response.data.status);
    });
    return response;
}
async function PATCH_shopByServerApi(api, headers, params) {
    const response = await axios_1.default
        .patch(api, params, {
        headers: headers,
    })
        .catch(function (error) {
        throw new common_1.HttpException(error.response.data.result.message, error.response.data.status);
    });
    return response.data;
}
function convertGlobalTelNo(telNo) {
    if (telNo.startsWith('0'))
        telNo = '82' + telNo.substring(1);
    return telNo;
}
exports.convertGlobalTelNo = convertGlobalTelNo;
function getDatesStartToLast(startDate, endDate) {
    try {
        const regex = RegExp(/^\d{4}-(0[1-9]|1[012])-(0[1-9]|[12][0-9]|3[01])$/);
        if (!(regex.test(startDate) && regex.test(endDate)))
            throw new common_1.HttpException('날자포멧이 아닙니다.', common_1.HttpStatus.BAD_REQUEST);
        const result = [];
        const curDate = new Date(startDate);
        while (curDate <= new Date(endDate)) {
            result.push(curDate.toISOString().split('T')[0]);
            curDate.setDate(curDate.getDate() + 1);
        }
        return result;
    }
    catch (error) {
        error;
    }
}
exports.getDatesStartToLast = getDatesStartToLast;
function getEventTime() {
    const hour = new Date().getHours();
    let strHour;
    if (hour < 10)
        strHour = '0' + hour;
    else
        strHour = hour.toString();
    const minutes = new Date().getMinutes();
    let strMinutes;
    if (minutes < 10)
        strMinutes = '00';
    else if (minutes < 20)
        strMinutes = '10';
    else if (minutes < 30)
        strMinutes = '20';
    else if (minutes < 40)
        strMinutes = '30';
    else if (minutes < 50)
        strMinutes = '40';
    else
        strMinutes = '50';
    return strHour + ':' + strMinutes;
}
exports.getEventTime = getEventTime;
function getUUID() {
    const tokens = (0, uuid_1.v4)().split('-');
    return tokens[0] + tokens[1] + tokens[2] + tokens[3] + tokens[4];
}
exports.getUUID = getUUID;
function getAlphabetByNumber(number) {
    if (number < 1 || number > 26) {
        throw new Error('Number must be between 1 and 26');
    }
    const alphabetStartCode = 'A'.charCodeAt(0);
    const letter = String.fromCharCode(alphabetStartCode + number - 1);
    return letter;
}
exports.getAlphabetByNumber = getAlphabetByNumber;
function formatDateToyyyyMMdd(date) {
    try {
        date.setHours(date.getHours() + 9);
        const year = date.getFullYear();
        const month = (date.getMonth() + 1).toString().padStart(2, '0');
        const day = date.getDate().toString().padStart(2, '0');
        return `${year}-${month}-${day}`;
    }
    catch (error) {
        return date.toString();
    }
}
exports.formatDateToyyyyMMdd = formatDateToyyyyMMdd;
function getRandomString(length) {
    const characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
    let result = '';
    for (let i = 0; i < length; i++) {
        const randomIndex = Math.floor(Math.random() * characters.length);
        result += characters.charAt(randomIndex);
    }
    return result;
}
exports.getRandomString = getRandomString;
function tossBankCodeToBankName(bankCode) {
    let bankName;
    switch (bankCode) {
        case '39':
            bankName = '경남은행';
            break;
        case '34':
            bankName = '광주은행';
            break;
        case '06':
            bankName = 'KB국민은행';
            break;
        case '03':
            bankName = 'IBK기업은행';
            break;
        case '11':
            bankName = 'NH농협은행';
            break;
        case '31':
            bankName = 'DGB대구은행';
            break;
        case '32':
            bankName = '부산은행';
            break;
        case '45':
            bankName = '새마을금고';
            break;
        case '07':
            bankName = 'Sh수협은행';
            break;
        case '88':
            bankName = '신한은행';
            break;
        case '20':
            bankName = '우리은행';
            break;
        case '71':
            bankName = '우체국예금보험';
            break;
        case '37':
            bankName = '전북은행';
            break;
        case '81':
            bankName = '하나은행';
            break;
    }
    return bankName;
}
exports.tossBankCodeToBankName = tossBankCodeToBankName;
function convertNumberFormat(input) {
    const decimalFormatter = new Intl.NumberFormat('en-US', {
        style: 'decimal',
        minimumFractionDigits: 0,
        maximumFractionDigits: 0,
    });
    return decimalFormatter.format(input);
}
exports.convertNumberFormat = convertNumberFormat;
function convertDeliveryType(deliveryType) {
    switch (deliveryType) {
        case 'PARCEL_DELIVERY':
            return '택배/등기/소포';
        default:
            return '직접배송(화물배달)';
    }
}
exports.convertDeliveryType = convertDeliveryType;
function isNullOrEmpty(value) {
    if (typeof value != 'string') {
        value = JSON.stringify(value);
        if (value === '{}')
            return true;
    }
    return typeof value !== 'string' || value.trim() === '';
}
exports.isNullOrEmpty = isNullOrEmpty;
//# sourceMappingURL=gsUtil.js.map