create table gs_common_product_info (
    sno INT PRIMARY KEY AUTO_INCREMENT,
    partnerSno INT NOT NULL COMMENT '고객사 번호',
    displayFl TINYINT(1) DEFAULT '1' NULL COMMENT '노출여부',
    title VARCHAR(100) NOT NULL COMMENT '제목',
    displayType ENUM ('ALWAYS', 'PERIOD') DEFAULT 'ALWAYS' NULL COMMENT '노출타입',
    startDt VARCHAR(30) NULL COMMENT '노출 시작일',
    endDt VARCHAR(30) NULL COMMENT '노출 종료일',
    productInfoType ENUM ('ALL', 'GOODS', 'CATEGORY', 'BRAND') DEFAULT 'ALL' NULL COMMENT '노출타겟선택',
    contentSameFl ENUM ('Y', 'N') DEFAULT 'Y' NULL COMMENT 'PC/MO 동일사용',
    contents TEXT DEFAULT NULL COMMENT 'PC 공통정보',
    mobileContents TEXT DEFAULT NULL COMMENT 'MO 공통정보',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP NULL COMMENT '등록일',
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP NULL ON UPDATE CURRENT_TIMESTAMP
);

ALTER TABLE gs_common_product_info ADD INDEX displayFl (displayFl);

CREATE TABLE gs_common_product_info_detail (
    sno INT PRIMARY KEY AUTO_INCREMENT,
    relSno INT NOT NULL COMMENT '상품 공통정보 리스트 sno',
    commonCd INT NOT NULL COMMENT '타겟 리스트 내 번호(상품, 카테고리, 브랜드)',
    targetFl ENUM ('ALL', 'GOODS', 'CATEGORY', 'BRAND') DEFAULT 'ALL' COMMENT '노출타겟선택',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '등록일',
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '수정일',
    CONSTRAINT gs_common_product_info_detail_ibfk_1
        FOREIGN KEY (relSno) REFERENCES gs_common_product_info (sno)
);

create index relSno on gs_common_product_info_detail (relSno);
ALTER TABLE gs_common_product_info_detail ADD INDEX commonCd (commonCd);


CREATE TABLE gs_searchRanking(
    partnerSno INT NOT NULL COMMENT '파트너번호',
    keyword VARCHAR(50) NOT NULL COMMENT '검색 키워드',
    count INT DEFAULT 1 NOT NULL COMMENT '검색수',
    searchDt VARCHAR(8) NOT NULL COMMENT '검색일(YYYYMMDD)',
    PRIMARY KEY(partnerSno, keyword, searchDt)
);

-- 에러처리 ip 추가
ALTER TABLE gs_exception ADD COLUMN ip VARCHAR(20) NULL AFTER errorCode;

-- 금지 검색어
CREATE TABLE gs_keywordBlackList(
    sno INT PRIMARY KEY AUTO_INCREMENT,
    keyword VARCHAR(50) NOT NULL UNIQUE,
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '등록일',
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '수정일'
);
