-- Survey
CREATE TABLE gs_survey(
    sno int PRIMARY KEY AUTO_INCREMENT,
    partnerSno INT NOT NULL COMMENT '고객사 번호',
    title VARCHAR(50) NOT NULL COMMENT '설문조사 제목',
    managerSno INT NOT NULL COMMENT '작성자 번호',
    participantsCount INT NOT NULL COMMENT '참여인원, (0이면 무제한)',
    displayType ENUM('ALWAYS', 'PERIOD') DEFAULT 'ALWAYS' COMMENT '노출타입',
    startDt VARCHAR(30) NULL COMMENT '노출 시작일',
    endDt VARCHAR(30) NULL COMMENT '노출 종료일',
    information TEXT NULL COMMENT '안내',
    memberFl BOOLEAN NOT NULL DEFAULT TRUE COMMENT '회원 전용 / 비회원 ',
    agreementFl BOOLEAN NOT NULL DEFAULT false COMMENT '약관 사용 여부',    
    agreement TEXT NULL COMMENT '약관',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updateDt TIMESTAMP DEFAULT  CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);
 INSERT INTO gs_survey SET
partnerSno=0, title='구매 만족도 설문조사', managerSno=0,
participantsCount=0,displayType='ALWAYS',memberFl=TRUE;

-- Question Template
CREATE TABLE gs_survey_question_template(
    sno int PRIMARY KEY AUTO_INCREMENT,
    templateTitle VARCHAR(200) NOT NULL COMMENT '템플릿명',
    partnerSno VARCHAR(100) NOT NULL COMMENT '고객사 번호, 0 이면 전체 고객사 사용 가능, 특정 고객사의 경우 구분자 ||(1||3||5)',
    templateCode CHAR(2) NOT NULL COMMENT '질문코드',
    preference TEXT NULL COMMENT '설정정보',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);
INSERT INTO gs_survey_question_template SET
templateTitle='객관식[단수선택]', partnerSno=0, templateCode='SC';

INSERT INTO gs_survey_question_template SET
templateTitle='객관식[복수선택]', partnerSno=0, templateCode='MC';


INSERT INTO gs_survey_question_template SET
templateTitle='주관식', partnerSno=0, templateCode='EQ';


[   
 {"description" : "선택가능개수", "type" : "number", },
 {"size":100, "placeholder" : "테스트"}
]
-- Question
CREATE TABLE gs_survey_question(
    sno int PRIMARY KEY AUTO_INCREMENT,
    surveySno INT NOT NULL COMMENT '설문번호',
    templateSno INT NOT NULL COMMENT '질문템플릿 번호',
    title VARCHAR(200) NOT NULL COMMENT '질문 제목',
    `require` BOOLEAN DEFAULT TRUE COMMENT '필수여부',
    isEtc BOOLEAN DEFAULT FALSE COMMENT '기타 사용 여부(기타의 경우 별도 입력 창 받는걸로)',
    preference TEXT NOT NULL COMMENT '설정정보',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);
ALTER TABLE gs_survey_question ADD COLUMN 
INSERT INTO gs_survey_question SET
surveySno = 1, templateSno=1,title='A shop 웹사이트에서 원하시는 상품을 쉽게 찾을수 있었습니까?', requireFl=TRUE, preference='{}';

INSERT INTO gs_survey_question SET
surveySno = 1, templateSno=1,title='배송기간에 만족하십니까?', requireFl=TRUE, preference='{}';

INSERT INTO gs_survey_question SET
surveySno = 1, templateSno=3,title='기타의견 혹은 A shop 멤버쉽 제도에 대한 의견이 있으시면 알려주세요 :)?', requireFl=TRUE, preference='{"cols" : "30", "rows" : "10", "maxlength" : "500", "placeholder" : "입력하세요"}';


CREATE TABLE gs_survey_answer (
    sno INT PRIMARY KEY AUTO_INCREMENT,
    surveySno INT NOT NULL COMMENT '설문번호',
    questionSno INT NOT NULL COMMENT '질문번호',
    answerText VARCHAR(500) NOT NULL COMMENT '답변',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '등록일시',
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '수정일시',
    CONSTRAINT fk_question FOREIGN KEY (questionSno) REFERENCES gs_survey_question(sno)
);

INSERT INTO gs_survey_answer SET
surveySno = 1, questionSno = 1, answerText='네';
INSERT INTO gs_survey_answer SET
surveySno = 1, questionSno = 1, answerText='아니오';

INSERT INTO gs_survey_answer SET
surveySno = 1, questionSno = 2, answerText='네';
INSERT INTO gs_survey_answer SET
surveySno = 1, questionSno = 2, answerText='아니오';


CREATE TABLE gs_survey_result(
    sno int PRIMARY KEY AUTO_INCREMENT,
    surveySno INT NOT NULL COMMENT '설문번호',
    memberNo  INT NOT NULL COMMENT '회원번호',
    memberId VARCHAR(35) NULL COMMENT '회원아이디',
    questionSno INT NOT NULL COMMENT '질문번호',
    answerSno INT NULL COMMENT '답변번호, 주관식의 경우 null',
    answerText VARCHAR(500) NULL COMMENT '답변내용',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);