-- 고객사 테이블
CREATE TABLE gs_partner(
    sno INT PRIMARY KEY AUTO_INCREMENT,
    partnerName VARCHAR(50) NOT NULL COMMENT '고객사명',
    siteUrl VARCHAR(300) NULL COMMENT 'siteUrl',
    ceoName VARCHAR(20) NOT NULL COMMENT '대표자명',
    companyTel VARCHAR(13) NULL COMMENT '전화번호',
    companyNo VARCHAR(12) NULL COMMENT '사업자번호',
    companyNoFile VARCHAR(500) NULL COMMENT '사업자번호 파일',
    bankCode VARCHAR(12) NULL COMMENT '은행',
    accountNo VARCHAR(50) NULL COMMENT '계좌번호',
    accountFile VARCHAR(500) NULL COMMENT '계좌번호 파일',
    zipcode CHAR(5) NULL  COMMENT '우편번호',
    address VARCHAR(200) NULL COMMENT '주소',
    addressSub VARCHAR(200) NULL COMMENT '주소상세',
    managerName VARCHAR(10) NULL COMMENT '담당자이름',
    managerTel VARCHAR(13) NULL COMMENT '담당자 전화번호',
    managerEmail VARCHAR(200) NULL COMMENT '담당자 이메일',
    solution ENUM('shopby', 'cafe24', 'si') DEFAULT 'shopby' COMMENT '사용 솔루션',
    apiUrl VARCHAR(200) NULL COMMENT '연동 API URL', 
    serverKey VARCHAR(50) NULL COMMENT 'serverKey',
    secretKey VARCHAR(50) NULL COMMENT 'secretKey',
    systemKey VARCHAR(50) NULL COMMENT 'systemKey',
    additionalInfo VARCHAR(500) NULL COMMENT '추가정보',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);

ALTER TABLE gs_partner ADD COLUMN longLivedToken VARCHAR(500) NULL COMMENT 'ShopBy용 장기토큰' AFTER systemKey;
ALTER TABLE gs_partner ADD COLUMN appToken VARCHAR(500) NULL COMMENT '프론트에서 사용 할 장기토큰' AFTER systemKey;
-- 관리자 테이블
CREATE TABLE gs_manager(
    sno INT PRIMARY KEY AUTO_INCREMENT,
    id VARCHAR(20) NOT NULL COMMENT '아이디',
    pwd VARCHAR(100) NOT NULL COMMENT '비밀번호',
    managerType ENUM ('admin', 'partner') DEFAULT 'partner' COMMENT '관리자티입',
    partnerSno INT NOT NULL COMMENT '고객사 번호',
    managerName VARCHAR(100) NOT NULL COMMENT '관리자 이름',
    managerTel VARCHAR(100) NOT NULL COMMENT '관리자 전화번호',
    managerEmail VARCHAR(100) NOT NULL COMMENT '관리자 이메일',
    status ENUM('Y','N') DEFAULT 'N' COMMENT '승인여부',
    authority VARCHAR(500) NULL COMMENT '권한',
    additionalInfo VARCHAR(500) NULL COMMENT '추가정보',
    accessToken varchar(500) NULL COMMENT 'accessToken',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN Key(partnerSno)REFERENCES gs_partner(sno)
);

-- 코드 관리
CREATE TABLE gs_code (
  codeKey varchar(255) PRIMARY KEY,
  parentKey varchar(255)  NULL,
  codeName varchar(255)  NOT NULL,
  codeValue varchar(255) NULL,
  rootFl enum('Y','N') DEFAULT 'N',
  displayFl enum('Y','N') DEFAULT 'N',
  regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
  updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);

-- 앱 관리
CREATE TABLE gs_appManager(
    sno INT PRIMARY KEY AUTO_INCREMENT,
    managerSno INT NOT NULL COMMENT '관리자 번호',
    appName VARCHAR(50) NOT NULL COMMENT '앱 이름',
    appUrl VARCHAR(200) NOT NULL COMMENT '앱 호출 url',
    appDesc TEXT NULL COMMENT '앱 설명',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN Key(managerSno)REFERENCES gs_manager(sno)
);

CREATE TABLE gs_appPartnerManager(
    sno INT PRIMARY KEY AUTO_INCREMENT,
    appSno INT, 
    partnerSno INT,
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN Key(appSno)REFERENCES gs_appManager(sno),
    FOREIGN Key(partnerSno)REFERENCES gs_partner(sno)
);
-- App
-- 매장관리 테이블
CREATE TABLE gs_shopManager(
    sno INT PRIMARY KEY AUTO_INCREMENT,
    partnerSno INT NOT NULL COMMENT '고객사 번호',
    shopName VARCHAR(100) NOT NULL COMMENT '매장명',
    shopTel VARCHAR(13) NULL COMMENT '매장 전화번호',
    shopCode VARCHAR(50) NULL COMMENT '매장코드',
    zipcode CHAR(5) NULL  COMMENT '우편번호',
    address VARCHAR(200) NULL COMMENT '주소',
    addressSub VARCHAR(200) NULL COMMENT '주소',
    city VARCHAR(10) NULL COMMENT '시/도 - 코드 연동',
    gu VARCHAR(10) NULL COMMENT '구 - 코드 연동',
    lat VARCHAR(50) NULL COMMENT '위도',
    lng VARCHAR(50) NULL COMMENT '경도',
    officeHour VARCHAR(20) NULL COMMENT '업무시간',
    description TEXT NULL COMMENT '매장설명',
    additionalInfo VARCHAR(500) NULL COMMENT '추가정보',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN Key(partnerSno)REFERENCES gs_partner(sno)
);

-- 1.0
-- deprecated
CREATE TABLE gs_brandManager(
    brandNo INT NOT NULL,
    partnerSno INT NOT NULL COMMENT '고객사 번호',
    brandNameKo VARCHAR(200) NOT NULL COMMENT '브랜드명',
    brandNameEn VARCHAR(200) NULL COMMENT '영문 브랜드명',
    displayBrandNo INT NULL COMMENT '몰별 전시브랜드 번호',
    brandNameType enum('NAME_KO', 'NAME_EN') DEFAULT 'NAME_KO' COMMENT '브랜드명 타입',
    brandLogoImage VARCHAR(500) NULL COMMENT '브랜드 로고 이미지',
    brandImage Text NULL COMMENT '브랜드 메인 이미지 ex)imgPath||linkUrl!!imgPath||linkUrl',
    brandDesc Text NULL COMMENT '브랜드 설명',
    additionalInfo VARCHAR(500) NULL COMMENT '추가정보',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN Key(partnerSno)REFERENCES gs_partner(sno),
    PRIMARY KEY(brandNo, partnerSno)
)

-- 2.0
CREATE TABLE gs_brandManager(
        brandNo INT NOT NULL,
        partnerSno INT NOT NULL COMMENT '고객사 번호',
        parentNo INT DEFAULT 0 COMMENT '상위 브랜드 번호(없으면 0)',
        mainName VARCHAR(30) NOT NULL COMMENT '브랜드명',
        subName VARCHAR(30) NULL COMMENT '부가 브랜드명',
        description TEXT NULL  COMMENT '브랜드설명',
        displayAreaContentUrl VARCHAR(500) NULL COMMENT '브랜드 이미지 또는 브랜드 관련 동영상 url',
        brandLogoImage VARCHAR(500) NULL COMMENT '브랜드 로고 이미지',
        brandExtraImage TEXT NULL COMMENT '브랜드 추가 이미지',
        extraInfo TEXT NULL COMMENT '추가정보',
        regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        FOREIGN Key(partnerSno)REFERENCES gs_partner(sno),
        PRIMARY KEY(brandNo, partnerSno)
);
ALTER TABLE gs_brandManager ADD COLUMN orderIndex INT NULL COMMENT '노출순서' AFTER extraInfo;
-- 고객사 별 알림톡 서비스회사/계정/키 관리 테이블
CREATE TABLE gs_alimtalkManager(
    sno INT PRIMARY KEY AUTO_INCREMENT,
    partnerSno INT NOT NULL COMMENT '고객사 번호',
    serviceProvider ENUM('INFOBANK','NHNCLOUD') COMMENT '알림톡 서비스 제공 업체',
    clientKey VARCHAR(200) NOT NULL COMMENT '클라이언트 키',
    clientPwd VARCHAR(200) NOT NULL COMMENT '클라이언트 패스워드',
    profileKey VARCHAR(200) NOT NULL COMMENT '발신 프로필 키',
    senderInfo VARCHAR(50) NULL COMMENT '전송자 정보',
    additionalInfo VARCHAR(500) NULL COMMENT '추가정보',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN Key(partnerSno)REFERENCES gs_partner(sno)
);
-- 알림톡 템플릿
CREATE TABLE gs_alimtalkTemplate(
    templateCode varchar(100) COMMENT '템플릿코드',
    partnerSno INT NOT NULL COMMENT '고객사 번호',
    templateTitle varchar(100) NOT NULL COMMENT '템플릿제목',
    msg text NOT NULL COMMENT '메시지',
    useButton enum('Y','N') default 'N' COMMENT '버튼 사용 여부',
    attachment text NULL COMMENT '버튼JSON',
    regDt datetime DEFAULT (now()),
    PRIMARY KEY(templateCode, partnerSno)
);
-- admin log

-- exception log
CREATE TABLE gs_exception(
    sno INT PRIMARY KEY AUTO_INCREMENT,
    partnerSno INT NOT NULL COMMENT '고객사 번호',  
    url varchar(500) NULL COMMENT '호출 url',
    request text NULL COMMENT 'request parameter',
    message TEXT NULL COMMENT 'exception message',
    errorCode varchar(10) NULL COMMENT 'errorCode',
    regDt datetime DEFAULT (now())
);
ALTER TABLE gs_exception MODIFY COLUMN message TEXT NULL COMMENT 'exception message';
-- 초기 데이터 생성
insert into gs_partner set partnerName='GeekStudio', ceoName='GeekStudio';
insert into gs_manager set id='geekstudio', pwd='$2b$10$CqTELzVPqUhFyTgPtssnBOqRtWogoJKLim0fJX5faYqsJNGNyHBO6', partnerSno=1, 
managerName='긱스튜디오', managerTel='070-5055-3400', managerEmail='biz@geekstudio.co.kr', status='Y';

CREATE TABLE gs_brand_like(
    partnerSno INT NOT NULL COMMENT '고객사 번호',
    memNo INT NOT NULL COMMENT '회원번호',
    brandNo INT NOT NULL COMMENT '브랜드 번호',
    PRIMARY KEY(partnerSno, memNo, brandNo)
);

CREATE TABLE gs_category_like(
    partnerSno INT NOT NULL COMMENT '고객사 번호',
    memNo INT NOT NULL COMMENT '회원번호',
    categoryNo INT NOT NULL COMMENT '카테고리 번호',
    PRIMARY KEY(partnerSno, memNo, categoryNo)
);


CREATE TABLE gs_logs(
  sno int PRIMARY KEY AUTO_INCREMENT,
  logType VARCHAR(100) NULL COMMENT '로그 구분',
  request text  NULL COMMENT 'request',
  response text NULL COMMENT 'response',
  regDt datetime DEFAULT (now()),
  updateDt datetime DEFAULT (now())
);

CREATE TABLE gs_memberSyncLog(
    sno int PRIMARY KEY AUTO_INCREMENT,
    partnerSno INT NOT NULL COMMENT '고객사 번호',
    memberId VARCHAR(200) NOT NULL COMMENT '회원아이디',
    request TEXT NOT NULL COMMENT 'request data',
    successFl ENUM('Y','N') DEFAULT 'Y' COMMENT '성공여부',
    message VARCHAR(500) NULL COMMENT '메시지',
    regDt datetime DEFAULT (now()),
    updateDt datetime DEFAULT (now())
);

ALTER TABLE gs_exception ADD COLUMN trace TEXT NULL COMMENT 'trace' AFTER message;

CREATE TABLE gs_magazine(
    sno int PRIMARY KEY AUTO_INCREMENT,
    partnerSno INT NOT NULL COMMENT '고객사 번호',
    managerSno INT NOT NULL COMMENT '작성자 번호',
    category VARCHAR(50) NULL COMMENT '카테고리',
    title VARCHAR(100) NOT NULL COMMENT '제목',
    subTitle VARCHAR(100) NULL COMMENT '소제목',
    contents TEXT NOT NULL COMMENT '컨텐츠',
    tag VARCHAR(200) NULL COMMENT '태그',
    displayFl BOOLEAN DEFAULT TRUE COMMENT '노출여부',
    displayType ENUM('ALWAYS', 'PERIOD') DEFAULT 'ALWAYS' COMMENT '노출타입',
    startDt VARCHAR(30) NULL COMMENT '노출 시작일',
    endDt VARCHAR(30) NULL COMMENT '노출 종료일',
    useComment BOOLEAN NOT NULL DEFAULT false COMMENT '댓글 사용 여부',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);
ALTER TABLE gs_magazine ADD COLUMN mainImg VARCHAR(500) NOT NULL COMMENT '대표이미지' AFTER category;

CREATE TABLE gs_comment(
    sno int PRIMARY KEY AUTO_INCREMENT,
    partnerSno INT NOT NULL COMMENT '고객사 번호',
    parentSno INT NULL COMMENT '상위글 번호 (대댓글은 지원 안함)',
    contentType ENUM('MAGAZINE', 'BOARD') NOT NULL COMMENT '코멘트 적용 타입',
    contentSno INT NOT NULL COMMENT '매거진/게시글 번호',
    memberId VARCHAR(50) NOT NULL COMMENT '작성자 아이디 (마스킹 처리)',
    memberNo INT NOT NULL COMMENT '작성자 회원번호',
    comment VARCHAR(200) NOT NULL COMMENT '댓글',
    attachment VARCHAR(500) NULL COMMENT '첨부파일',
    regDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updateDt TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);